Match class

Encapsulates a matching block when comparing two inputs.

Implemented types
Mixed-in types

Constructors

Match({required int sourceStart, required int targetStart, required int length})
Constructs a new match.
const

Properties

defaultToStringPrinter → ObjectPrinter
Override to configure the empty ObjectPrinter.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
length → int
The length of the match.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceStart → int
The start of the match in the source.
final
targetStart → int
The start of the match in the target.
final
toStringPrinter → ObjectPrinter
Override and call super to add values to the ObjectPrinter.
no setteroverride

Methods

compareTo(Match other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Standard Object.toString implementation. Do not override, instead implement toStringPrinter to customize.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override