Operation class

Encapsulates an operation when comparing two inputs.

Mixed-in types
Annotations
  • @immutable

Constructors

Operation(OperationType type, {required int sourceStart, required int sourceEnd, required int targetStart, required int targetEnd})
Constructs a new operation.
const

Properties

defaultToStringPrinter → ObjectPrinter
Override to configure the empty ObjectPrinter.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceEnd → int
The end of the operation in the source (exclusive).
final
sourceStart → int
The start of the operation in the source.
final
targetEnd → int
The end of the operation in the target (exclusive).
final
targetStart → int
The start of the operation in the target.
final
toStringPrinter → ObjectPrinter
Override and call super to add values to the ObjectPrinter.
no setteroverride
type → OperationType
The type of the operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Standard Object.toString implementation. Do not override, instead implement toStringPrinter to customize.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const Operation
Constructs an empty operation.