ReadableDiffer class

Generates a highly configurable diff output.

Inheritance

Constructors

ReadableDiffer({Predicate1<String>? lineJunk, Predicate1<int>? charJunk, Printer<String>? replaceLine, Printer<String>? deleteLine, Printer<String>? insertLine, Printer<String>? equalLine})

Properties

charJunk → Predicate1<int>?
final
deleteLine → Printer<String>
final
equalLine → Printer<String>
final
hashCode → int
The hash code for this object.
no setterinherited
insertLine → Printer<String>
final
lineJunk → Predicate1<String>?
final
replaceLine → Printer<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareLines(Iterable<String> source, Iterable<String> target, {String? sourceLabel, String? targetLabel}) → Iterable<String>
Compares two iterables of lines from source to target.
override
compareStrings(String source, String target, {String? sourceLabel, String? targetLabel}) → Iterable<String>
Compares two strings from source to target.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited