Period enum
Different kinds of repeating periodic timestamps.
Values
- millennially → const Period
-
const Period(TimeUnit.millennium) - centennially → const Period
-
const Period(TimeUnit.century) - decennially → const Period
-
const Period(TimeUnit.decade) - yearly → const Period
-
const Period(TimeUnit.year) - quarterly → const Period
-
const Period(TimeUnit.quarter) - monthly → const Period
-
const Period(TimeUnit.month) - weekly → const Period
-
const Period(TimeUnit.week) - daily → const Period
-
const Period(TimeUnit.day) - hourly → const Period
-
const Period(TimeUnit.hour) - minutely → const Period
-
const Period(TimeUnit.minute) - secondly → const Period
-
const Period(TimeUnit.second) - millisecondly → const Period
-
const Period(TimeUnit.millisecond) - microsecondly → const Period
-
const Period(TimeUnit.microsecond)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeUnit → TimeUnit
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited