PrimeSieve class abstract

Abstract sieve implementation for primes up to and including max.

Implementers

Constructors

PrimeSieve(int max)
Constructs a prime sieve up to max. Throws a RangeError if max is negative.

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → int
The maximum number this sieve supports.
final
primes → Iterable<int>
Returns an Iterable of all primes up to and including max.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isPrime(int value) → bool
Tests if a value is prime. Throws a RangeError exception if value is larger than max.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited