RangeIterator<T> class

An Iterator over a Range.

Implemented types
Available extensions

Constructors

RangeIterator.atEnd(Range<T> range)
Constructs a RangeIterator at the end of the range.
RangeIterator.atStart(Range<T> range)
Constructs a RangeIterator at the beginning of the range.

Properties

current → T
The current element.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
range Range<T>
The underlying range being iterated over.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJSIterator JSIterator<T>

Available on Iterator<T>, provided by the IteratorToJSIterator extension

A JSIterator wrapper that proxies to the Dart iterator API.
no setter

Methods

moveNext() bool
Advances the iterator to the next element of the iteration.
override
movePrevious() bool
Advances the iterator to the previous element of the iteration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited