Tuple5<T1, T2, T3, T4, T5> extension

Extension methods on Record with 5 positional elements.

on
  • (T1, T2, T3, T4, T5)

Properties

fifth → T5

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the fifth element of this tuple.
no setter
first → T1

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the first element of this tuple.
no setter
fourth → T4

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the fourth element of this tuple.
no setter
iterable → Iterable

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

An (untyped) Iterable over the values of this tuple.
no setter
last → T5

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the last element of this tuple.
no setter
length → int

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the number of elements in the tuple.
no setter
second → T2

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the second element of this tuple.
no setter
third → T3

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns the third element of this tuple.
no setter

Methods

addFifth<T>(T value) → (T1, T2, T3, T4, T, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the fifth position.
addFirst<T>(T value) → (T, T1, T2, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the first position.
addFourth<T>(T value) → (T1, T2, T3, T, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the fourth position.
addLast<T>(T value) → (T1, T2, T3, T4, T5, T)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the last position.
addSecond<T>(T value) → (T1, T, T2, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the second position.
addSixth<T>(T value) → (T1, T2, T3, T4, T5, T)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the sixth position.
addThird<T>(T value) → (T1, T2, T, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with value added at the third position.
map<R>(R callback(T1 first, T2 second, T3 third, T4 fourth, T5 fifth)) → R

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Applies the values of this tuple to an 5-ary function.
removeFifth() → (T1, T2, T3, T4)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the fifth element removed.
removeFirst() → (T2, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the first element removed.
removeFourth() → (T1, T2, T3, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the fourth element removed.
removeLast() → (T1, T2, T3, T4)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the last element removed.
removeSecond() → (T1, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the second element removed.
removeThird() → (T1, T2, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the third element removed.
toList() → List

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

An (untyped) List with the values of this tuple.
toSet() → Set

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

An (untyped) Set with the unique values of this tuple.
withFifth<T>(T value) → (T1, T2, T3, T4, T)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the fifth element replaced by value.
withFirst<T>(T value) → (T, T2, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the first element replaced by value.
withFourth<T>(T value) → (T1, T2, T3, T, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the fourth element replaced by value.
withLast<T>(T value) → (T1, T2, T3, T4, T)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the last element replaced by value.
withSecond<T>(T value) → (T1, T, T3, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the second element replaced by value.
withThird<T>(T value) → (T1, T2, T, T4, T5)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

Returns a new tuple with the third element replaced by value.

Static Methods

fromList<T>(List<T> list) → (T, T, T, T, T)

Available on (T1, T2, T3, T4, T5), provided by the Tuple5 extension

List constructor.