removeSecond method
(T1, T3, T4, T5, T6, T7, T8)
removeSecond()
Returns a new tuple with the second element removed.
Implementation
(T1, T3, T4, T5, T6, T7, T8) removeSecond() => ($1, $3, $4, $5, $6, $7, $8);
Returns a new tuple with the second element removed.
(T1, T3, T4, T5, T6, T7, T8) removeSecond() => ($1, $3, $4, $5, $6, $7, $8);